function [data, name, fs,info]=ReadAndSyncSensors2(f,syncperiod)

%Octobre 2018 ReadAndSyncSensors2 reads 3D accelertion, angular velocty and
%Magneticfield data (if present) and cuts out the temperature signal

% Sample rates of all sensors have been checked, signals are
% resampled at the exact intended sample frequency (sf).
% Sensor specific calibration factors are applied if present following manual
% calibration procedures. When sensors have been manually calibrated,
% calibratedforAccelerationandGyros and/or calibratedforMagneticfield must be changed
% for each individual sensor in the code below to value 1 (their default value =0)
% The calbriation factors must be manually copied into the code for each indidual sensor .
% Calibrations can be executed with calibrateAccGyro.m and/or calibrateMagmeto.m
% When a mechanical synchronization peak is detected in the beginning of the
% signals, within the defined syncperiod (otherwise syncperiod=10 sec by
% default),samples before this peak are removed.
%
% The battery can be charged via USB connection (e.g. with PC or laptop).
% It is best to switch the sensor of during charging. There is no charge indicator,
% but recharging a completely empty battery takes about 45 min. Sensors will automatically
% stop sampling when voltage drops below 3.6 V. This is to prevent battery voltage to become
% too low for recharging. The voltage of the battery can be estimated by loading the last data
% file from the SD-card of the sensor in Matlab using by typing the following command in the work
% space followed by <enter>:
% [data, f1, fs]=ReadAndSyncSensors2(); (include the semicolon)
% The number(Voltage) after the text 'Batt:' as  displayed in the Matlab work space
% is a good approximation of the battery voltage. When completely loaded Voltage is about 4.1 V.
% A fully charged battery allows you to sample for over one hour when all signals (9 DOF plus temperature)
% are sampled at 500 Hz, sample time increases to over two hours when Magnetos are not on..


% 26 octobre 2018 calibratedforAccelerationandGyros and
% calibratedforMagneticfield have been introduced (default 0). These must be
% manually changed to 1 after calibration. HOw? see CASE 128
% at line 100 it is checked if Magetos were on with some changes around line 835
% all to reduce the number of if statements with each sensor CASE statement
%jan 2020 detection for syncpeak at the end of the file included, in case a
%mechanical syncpeak at the beginning of the data file is missing

if nargin<2
    % nrChans=7;
    syncperiod=30;% syncperiod in seconden k
end
if ~nargin || isempty(f)
    [f,d]=uigetfile('*.Dat','Select a file to read and sync');
    if ~f
        return
    end
    f=[d f];
end

[~,name,~] = fileparts(f);

fid=fopen(f, 'r');%fid=file-handle
[tmp, pos]=fread(fid,16384);
fseek(fid,0,'eof');
eof=ftell(fid);
fclose(fid);

%%header inlezen en tonen
index=find(tmp==26);%getal 26 geeft aan waar de header stopt is andere positie als magnetos aan staan
if isempty(index)
    return
end
pos=index(1);

fid=fopen(f, 'r');
fseek(fid, 0, 'eof');
l=ftell(fid);
fseek(fid, 0, 'bof');
str=(fread(fid, pos, '*char'))'



nrChan= str(strfind(str,'Channels')+10:strfind(str,'Channels')+12);
nrChans=str2num(nrChan);



data=fread(fid, [nrChans round(l/nrChans/2)], 'int16')';


fclose(fid);
if nrChans==7
    data=[data(:,1:3) data(:,5:7)];%temperatuur signaal eruit
else
    data=[data(:,1:3) data(:,5:10)];%temperatuur signaal eruit en 3 magnetos erbij
end

startindex=strfind(str,'SampleFrequency')+18; %ingestelde Samplerfreqeuntie opzoeken in header
fs=str2double(str(startindex:startindex+3));

if length(data)<=syncperiod*fs
    
    syncperiod=(length(data)./fs)-1;% anders worden hele korte signalen misschien niet ingelezen omdat syncperiod standaard op 5 sec staat als hij niet wordt meegegeven
end

sensnum=deblank(str(9:11));

sensnum2=str2double(sensnum);

factor=fs/500;% het vaststellen van de exacte sample frequentie is op 500 Hz gebeurd, dus bij hersampelen is deze factor nodig
fssensor = fs;
calibratedforAccelerationandGyros=0;%staat standaard op 0, wordt vervangen door 1 indien de sensor goed met de hand geijkt is
calibratedforMagneticfield=0;
offSetAcc = [0 0 0];
scaleFactorAcc = [0 0 0];
offSetGyro = [0 0 0];
offSetMag = [0 0 0];
scaleFactorMag = [0 0 0];

% invert y- and z-axis accelerometers
xAcc = data(:,1);
yAcc = -data(:,2);
zAcc = -data(:,3);

% invert y- and z-axis accelerometers
xGyro = data(:,4);
yGyro = -data(:,5);
zGyro = -data(:,6);

% if the magnetos have been sampled along with the accelearation and
% angular velocities, swap x and y, invert z
if size(data,2)==9
    xMag = data(:,8);
    yMag = data(:,7);
    zMag = -data(:,9);
end

%% exacte sample frequentie en evntuele ijking per sensor bepalen en signalen resampelen
switch sensnum2
    case 49%wit jan 2020
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0093295379391*factor;
        calibratedforAccelerationandGyros=1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [-16.2241230214128,-20.1507198664908,-95.7638827374836];
        scaleFactorAcc = [0.00479510190670759,0.00474960955857848,0.00480112807446835];
        offSetGyro = [-27.6761268781302,4.61101836393990,-2.59682804674457];
        offSetMag = [-98,-11.5000000000000,-131];
        scaleFactorMag = [0.00657894736842105,0.00647249190938511,0.00684931506849315];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);%adjusting the sample rate to exactly 500Hz
        
    case 50 %blauw bij TOD
        %fssensor=500.005*factor;%more exact, true, sample rate
        fssensor=500.0025763412862*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+12).*0.0047721;
        data(:,2)=(data(:,2)+6).*0.0047554;
        data(:,3)=(data(:,3)+47).*0.0047570;
        data(:,4)=(data(:,4)+5).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)+0).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+8).*0.06104*2*pi/360;
        %as orientatie correctie naar afbeelding op doosje
        data(:,2)=data(:,2).*-1;
        data(:,3)=data(:,3).*-1;
        data(:,5)=data(:,5).*-1;
        data(:,6)=data(:,6).*-1;
        [ data] = sfcorrection( data, fssensor, fs);%adjusting the sample rate to exactly 500Hz
    case 51 %geel klopt fs?bij TOD
        %fssensor=500.005*factor;%more exact, true, sample rate
        fssensor=500.0036163321314*factor;
        calibratedforAccelerationandGyros=1;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [7.133204171450416 -13.379251527698329 -61.946648865469797];
        scaleFactorAcc = [0.004752475688081   0.004759707450821   0.004734517907136];
        offSetGyro = [19.500000000000000  -2.586004691164973   7.354964816262705];
        offSetMag = [429.5000  -66.0000  145.0000];
        scaleFactorMag = [0.006600660066007   0.006535947712418   0.007042253521127];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);%adjusting the sample rate to exactly 500Hz
        
    case 52 %roze klopt FS Jo waarschijnlijk wel? zoek?
        %fssensor=500.0056082*factor;
        fssensor=500.0043395922803*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)-7).*0.0047680;
        data(:,2)=(data(:,2)+7).*0.0047671;
        data(:,3)=(data(:,3)-12).*0.0047260;
        data(:,4)=(data(:,4)+3).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-10).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)-4).*0.06104*2*pi/360;
        %as orientatie correctie naar afbeelding op doosje
        data(:,2)=data(:,2).*-1;
        data(:,3)=data(:,3).*-1;
        data(:,5)=data(:,5).*-1;
        data(:,6)=data(:,6).*-1;
        [ data] = sfcorrection( data, fssensor, fs);
    case 53 %groen bij TOD
        %fssensor=500.0056082*factor;
        fssensor= 500.0035731191217*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)-23).*0.0048005;
        data(:,2)=(data(:,2)-4).*0.0047645;
        data(:,3)=(data(:,3)+26).*0.0047578;
        data(:,4)=(data(:,4)-2).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-2).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+9).*0.06104*2*pi/360;
        %as orientatie correctie naar afbeelding op doosje
        data(:,2)=data(:,2).*-1;
        data(:,3)=data(:,3).*-1;
        data(:,5)=data(:,5).*-1;
        data(:,6)=data(:,6).*-1;
        [ data] = sfcorrection( data, fssensor, fs);
    case 54 %paars bij TOD
        
        %fssensor=500.0072907*factor;
        fssensor=500.0061477334984*factor;
        
        %as orientatie correctie naar afbeelding op doosje
        calibratedforAccelerationandGyros=1;%is goed jo
        data(:,1)=(data(:,1)+11).*0.0047520;
        data(:,2)=(data(:,2)-6).*0.0047557;
        data(:,3)=(data(:,3)-49).*0.0047378;
        data(:,4)=(data(:,4)+22).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-9).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)-18).*0.06104*2*pi/360;
        
        
        [ data] = sfcorrection( data, fssensor, fs);
        %     data(:,2)=data(:,2).*-1; %as omkering is niet nodig gecheckt door Jo
        %     en Erik Wilmes
        %     data(:,3)=data(:,3).*-1;
        %     data(:,5)=data(:,5).*-1;
        %     data(:,6)=data(:,6).*-1;
        
        
    case 55 %rood bij TOD
        
        %fssensor=500.0072907*factor;
        fssensor=500.0054389115765*factor;
        
        %as orientatie correctie naar afbeelding op doosje
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+26).*0.0048144;
        data(:,2)=(data(:,2)+0).*0.0048136;
        data(:,3)=(data(:,3)-23).*0.0047984;
        data(:,4)=(data(:,4)-25).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)+0).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+1).*0.06104*2*pi/360;
        
        data(:,2)=data(:,2).*-1;
        data(:,3)=data(:,3).*-1;
        data(:,5)=data(:,5).*-1;
        data(:,6)=data(:,6).*-1;
        [ data] = sfcorrection( data, fssensor, fs);
case 56 %aubergine zoek kapot?
        %fssensor=500.0064*factor;
        fssensor=500.0047741032204*factor;
        %as orientatie correctie naar afbeelding op doosje
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;%jan 2019 niet te callibreren op Magneto
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00475639396531993,0.00476741032074320,0.00480416603658822];
        offSetAcc= [-17.0187345754871,-5.14496124031007,10.9964556131515];
        offSetGyro=[14.5946180555556,-22.3880208333333,2.41406250000000];
        offSetMag = [160,174,79];
        scaleFactorMag = [0.973084886128364,0.895238095238095,1.16915422885572];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 60 %
    fssensor=500.0055181669544*factor;
        
        %fssensor=500*factor;
         % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00478924941272291,0.00480757970108669,0.00477605272790862];
        offSetAcc= [-28.3825837071838,-1.44099880465785,125.138498332710];
        offSetGyro=[-23.4960739030023,-10.8840646651270,-9.30531177829099];
        offSetMag = [4.50000000000000,-92,176];
        scaleFactorMag = [1.11660329531052,1.09577114427861,0.839047619047619];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 100 %rood
        
        fssensor=500.0091573141169*factor;
        calibratedforAccelerationandGyros = 1;%jan 2020
        calibratedforMagneticfield = 1;%jan 2020
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00476328390064449,0.00476444938288740,0.00476081379145585];
        offSetAcc= [-50.3893804589090,-6.06268371993474,-3.19562411506968];
        offSetGyro=[-28.3437500000000,12.6736111111111,10.8359375000000];
        
        
        offSetMag = [-15.5000000000000,35,100];
        scaleFactorMag = [0.00668896321070234,0.00657894736842105,0.00704225352112676];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 101 %geel spetmeber 2018
        fssensor=500.0085566762953*factor;%nov 2019
        calibratedforAccelerationandGyros = 1;%jan 2020
        calibratedforMagneticfield = 1;%jan 2020
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00477307256782754,0.00481857933658618,0.00473562708311362];
        offSetAcc= [-23.9438292014015,-7.15192315740285,-441.486149523101];
        offSetGyro=[-23.1481481481482,6.32694763729247,15.1590038314176];
        
        
        offSetMag = [123,40.5000000000000,-84.5000000000000];
        scaleFactorMag = [0.00653594771241830,0.00668896321070234,0.00711743772241993];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 102 %bruin
        fssensor=500.0080673908325*factor;
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00476828520916796,0.00476526082789460,0.00479253433859801];
        offSetAcc= [-8.26767717090138,-7.67818768661414,-68.2159870350362];
        offSetGyro=[-17.9466101694915,6.37457627118644,21.5508474576271];
        
%         offSetMag = [110.0000   47.5000  -13.0000];
%         scaleFactorMag = [0.985347985347985 0.971119133574007 1.04669260700389];
        offSetMag = [-32.0000  -67.0000  105.5000];
        scaleFactorMag = [0.006535947712418   0.006578947368421   0.006968641114983];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 103 %oranje
        fssensor=500.0083211341688*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+11).*0.0048068;
        data(:,2)=(data(:,2)-4).*0.0047935;
        data(:,3)=(data(:,3)-71).*0.0047457;
        
        data(:,4)=(data(:,4)-4).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-22).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+39).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
    case 104 %blauw
        fssensor=500.0084539214976*factor;
        calibratedforAccelerationandGyros=0;
        [ data] = sfcorrection( data, fssensor, fs);
    case 105 %groen geijkt op 27-02-2018
        fssensor=500.0072088117374*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+7).*0.0047662;
        data(:,2)=(data(:,2)-10).*0.0047783;
        data(:,3)=(data(:,3)-37).*0.0048016;
        data(:,4)=(data(:,4)+0).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)+24).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+8).*0.06104*2*pi/360;
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 106%paars
        fssensor=500.0091107198336*factor;
        calibratedforAccelerationandGyros=0;
        [ data] = sfcorrection( data, fssensor, fs);
    case 107 %wit geijkt op 29-10-2018
        fssensor=  500.0075444835649 *factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration Factors
        scaleFactorAcc = [0.004789440904080   0.004806200642528   0.004784836948417];
        offSetAcc = [-24.344280173857783  -4.873065315042368 -13.880678733792024];
        offSetGyro =[-1.055593220338983   2.995254237288135   3.121016949152542];
        %         offSetMag = [56   -19.5    50.5];
        %         scaleFactorMag = [1.008948545861298   0.973031283710895   1.019209039548023];
        offSetMag = [50.5 -22 61.5];
        scaleFactorMag = [0.006872852233677   0.006896551724138   0.007380073800738];
        
        D =  [  0.009858116587072   0.000156638399670  -0.000086697656128;...
            -0.000346435898275   0.010002678432776  -0.000045245229197;...
            0.000031821560445   0.000072144276743   0.010536955536921];
        
        o_0 = [50.423914399055413 -21.568640231283474 65.722667947044556]';
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
            
            %         data(:,7) = xMag;
            %         data(:,8) = yMag;
            %         data(:,9) = zMag;
            %         for i = 1:size(data,1)
            %             data(i,7:9) = (D*(data(i,7:9)'-o_0))';
            %         end
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 108 %zwart geijkt op 28-02-2018 en opniieuw jan 2020
        fssensor=500.0095274290145*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %offSetAcc = [-1275.857392333382   4.299729901493  -108.270038630360];
        offSetAcc =[-1156.98287051287 3.81302155956632 -103.471145564169];
        scaleFactorAcc = [0.00479367056646811 0.00477470642859561 0.00478253256405734];
        offSetGyro = [-22.8652526512789 49.5327510917031 -4.76107298814722];
        %         offSetMag = [125.5000  145.0000   -9.5000];
        %         scaleFactorMag = [0.983164983164983   0.986486486486487   1.031802120141343];
        %offSetMag = [132.5  145 -11];
        offSetMag = [94.5000000000000 -12 36];%jan 2020
        %scaleFactorMag = [0.006968641114983   0.006993006993007   0.007407407407407];
        scaleFactorMag = [0.00664451827242525 0.00657894736842105 0.00704225352112676];%jan 2020
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 109 %paars april 2017
        %fssensor=500.0090*factor;
        %fssensor=500.0072*factor;
        fssensor=500.0073593499011*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+27).*0.0047649;
        data(:,2)=(data(:,2)-9).*0.0047954;
        data(:,3)=(data(:,3)+2).*0.0047975;
        data(:,4)=(data(:,4)+14).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)+23).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+5).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
        
        
        %sensoren 110 tm 115 lopen gesynced met deze sample freqs, jo 6 febr 2015
        %en gechecked met sensor 101 en 103 uit ander serie
    case 110 %rood april 2017
        %fssensor=500.0090*factor;
        %fssensor=500.0101769*factor;
        fssensor=500.0090977834454*factor;
        calibratedforAccelerationandGyros=1;
        %     data(:,1)=(data(:,1)-40).*0.0047828;
        %     data(:,2)=(data(:,2)-17).*0.0047697;
        %     data(:,3)=(data(:,3)-18).*0.0047404;
        %     data(:,4)=(data(:,4)+30).*0.06104*2*pi/360;%rad/s
        %     data(:,5)=(data(:,5)-2).*0.06104*2*pi/360;
        %     data(:,6)=(data(:,6)+22).*0.06104*2*pi/360;
        data(:,1)=(data(:,1)-8).*0.0047822;
        data(:,2)=(data(:,2)-14).*0.0047699;
        data(:,3)=(data(:,3)-4).*0.0047427;
        data(:,4)=(data(:,4)+24).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-2).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+10).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
    case 111 %geel april 2017 en opnieuw jan 2020
        fssensor=500.0083211341688*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00480172218990825 0.00474917124329866 0.00473599978665763];
        offSetAcc= [-20.8903587503534,-2.07361205006850,71.0064547667907];
        offSetGyro=[-0.0603136308805790 10.0253317249698 3.57599517490953];
        %         offSetMag = [54,-28.5000000000000,-22.5000000000000];
        %         scaleFactorMag = [0.987654320987654,0.962695547533093,1.05401844532279];
        %offSetMag = [52,-26,-23];%april 2017
        offSetMag=[47.5000000000000 -27 -18.5000000000000];
        %         scaleFactorMag = [0.006756756756757, 0.006535947712418, 0.006993006993007];
        scaleFactorMag = [0.00673400673400673 0.00653594771241830 0.00692041522491350];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 112 %bruin
        %fssensor=500.0090*factor;
        %fssensor=500.0055867*factor;
        fssensor=500.0046283466728*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+18).*0.0047729;
        data(:,2)=(data(:,2)-3).*0.0047753;
        data(:,3)=(data(:,3)-72).*0.0048041;
        data(:,4)=(data(:,4)-20).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-0).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+14).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
    case 113 %oranje
        %fssensor=500.0090*factor;
        %fssensor=500.0096267*factor;
        fssensor=500.0070613141195*factor;
        
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)-7).*0.0047591;
        data(:,2)=(data(:,2)-16).*0.0047828;
        data(:,3)=(data(:,3)+22).*0.0047490;
        data(:,4)=(data(:,4)+5).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-12).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+2).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
    case 114 %blauw
        fssensor=500.0062132900411*factor;
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-7.159275383707154  -9.968427768136621 -22.996383598394118];
        scaleFactorAcc = [0.004782928301813   0.004783780016004   0.004769243705128];
        offSetGyro = [22.104683195592287  20.236455463728191  -1.671258034894399];
        offSetMag = [18 -63.5 9];
        scaleFactorMag = [0.007042253521127   0.007220216606498   0.007299270072993];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 115 %groen
        %fssensor=500.0090*factor;
        %fssensor=500.0112153*factor;
        fssensor=500.0088756569747*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)-3).*0.0047829;
        data(:,2)=(data(:,2)-17).*0.0047803;
        data(:,3)=(data(:,3)-13).*0.0047520;
        data(:,4)=(data(:,4)+17).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-12).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+18).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 116 %paars
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0064824687167*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-9.073633514360608  -7.168136674294715 -28.987486357249054];
        scaleFactorAcc = [0.004766064600342   0.004774069163559   0.004797582214639];
        offSetGyro = [11.364155251141552   9.152968036529680  -4.136986301369863];
        offSetMag = [4   -87    41];
        scaleFactorMag = [0.006849315068493   0.006944444444444   0.007352941176471];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 119 %paars
         %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0089078796449*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00478499663337698,0.00475990792311952,0.00475704584245220];
        offSetAcc= [-5.81393529931336,-13.1937089385983,-7.91834197335697];
        offSetGyro=[-26.3728813559322,12.8752542372881,-5.67389830508475];
%         offSetMag = [-58,65.5000000000000,12];
%         scaleFactorMag = [0.988549618320611,0.970037453183521,1.04435483870968];
        offSetMag = [-64,66.5000000000000,14];
        scaleFactorMag = [0.006802721088435   0.006688963210702   0.007194244604317];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3); 
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 120 %rood
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0059386328421*factor;
        calibratedforAccelerationandGyros=1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [-8.4962   -5.5515  134.7470];
        scaleFactorAcc = [0.004780991535026   0.004761813022455   0.004763226495076];
        offSetGyro = [-3.070621468926554 -10.578692493946731  -3.098062953995157];
        
        offSetMag = [-28.0000  -94.5000  -21.5000];
        scaleFactorMag = [0.007092198581560   0.007017543859649   0.007117437722420];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 121 %geel
      
        fssensor=500.0086062164649 *factor;
         % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00480515733659235 0.00475469638458754 0.00481262676801161];
        offSetAcc= [-11.9980288999410 -10.5170462497376 -34.0525587213313];
        offSetGyro=[11.7330316742081 -18.4276018099548 15.9018099547511];
%         offSetMag = [-53 98 23];
%         scaleFactorMag = [0.982102908277405 0.988738738738739 1.03051643192488];
        offSetMag = [-54.5000000000000,108,30.5000000000000];
        scaleFactorMag = [0.006644518272425   0.006535947712418   0.007017543859649];
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 122 %bruin aug 2017

        fssensor=500.0086298402547*factor;
        calibratedforAccelerationandGyros=1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [0.584167818129799  -7.229789792223983   5.459642967637592];
        scaleFactorAcc = [0.004784558319474   0.004774047484720   0.004787054450071];
        offSetGyro = [-43.212145110410091 -14.515378548895900 -10.763406940063092];
        
        offSetMag = [189    41    30];
        scaleFactorMag = [0.006993006993007   0.006896551724138   0.007407407407407];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 123 %oranje aug 2017
        %fssensor=500.0090*factor;
        %fssensor=500.0078425*factor;
        fssensor=500.0082100727840*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+18).*0.0048050;
        data(:,2)=(data(:,2)-19).*0.0047984;
        data(:,3)=(data(:,3)-32).*0.0047574;
        data(:,4)=(data(:,4)-4).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-17).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)+18).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
    case 124 %blauw aug 2017
       fssensor=500.0081784525521*factor;
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00478401245910318,0.00478826196302204,0.00474726599430799];
        offSetAcc= [-37.0035063113603,4.26365644429484,386.289620535714];
        offSetGyro=[-7.19072463768116,-13.5031884057971,23.6591304347826];
%         offSetMag = [110.0000   47.5000  -13.0000];
%         scaleFactorMag = [1.01767676767677 0.995061728395062 0.987745098039216];
          offSetMag = [10,13,144];
        scaleFactorMag = [0.006711409395973   0.006711409395973   0.007042253521127];
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 125 %groen april 2017
        %fssensor=500.0090*factor;
        %fssensor=500.0078425*factor;
        fssensor=500.0086625749106*factor;
        calibratedforAccelerationandGyros=1;
        data(:,1)=(data(:,1)+20).*0.0047838;
        data(:,2)=(data(:,2)-4).*0.0047564;
        data(:,3)=(data(:,3)+429).*0.0047520;
        data(:,4)=(data(:,4)+25).*0.06104*2*pi/360;%rad/s
        data(:,5)=(data(:,5)-21).*0.06104*2*pi/360;
        data(:,6)=(data(:,6)-11).*0.06104*2*pi/360;
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 126 %lila
         %fssensor=500.0065*factor;
        fssensor=500.0069280446349*factor;
        %fssensor=500*factor;
         %fssensor=500*factor;
         % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.004752949159057   0.004808109405677   0.004742635076355];
        offSetAcc= [-15.245616968464674 -16.737918394175495  66.978889352420651];
        offSetGyro=[4.030561945448571  -1.853105488005258  20.776864935918500];
        offSetMag = [47.0000   46.0000  -28.5];
        scaleFactorMag = [0.006756756756757   0.006756756756757   0.007117437722420];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 127 %wit
           %fssensor=500.0065*factor;
        fssensor=500.0089707281855*factor;
        %fssensor=500*factor;
         % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00481199034853422,0.00477076837272887,0.00475292170312950];
        offSetAcc= [-2.55523934286862,-7.47217821403706,-16.7618219858871];
        offSetGyro=[11.2648335745297,16.6362759286059,-6.67438494934877];
%         offSetMag = [79.5000000000000,28.5000000000000,-30.5000000000000];
%         scaleFactorMag = [[0.984435797665370,0.984435797665370,1.03265306122449]];
          offSetMag = [78,31,-30];
        scaleFactorMag = [0.006896551724138   0.006993006993007   0.007352941176471];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 128 %zwart
        
        fssensor=500.0084573176930*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % scale factors and offsets accelerometer and gyro have been
        % calculated with 'calibrateAccGyro.m'; Magnetometer offsets with
        % have been calculated using 'VisMagCal'
        scaleFactorAcc=[0.00476189372273451 0.00480050085262391 0.00479287276699654];
        offSetAcc= [-28.0916382299849 -11.5888858570527 -47.3112215749860];
        offSetGyro=[11.0794520547945 -5.85547945205479 5.74178082191781];
        offSetMag = [103.5000   48.5000   -9.5000];
        scaleFactorMag = [0.972327044025157 0.972327044025157 1.06035665294925];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
        
    case 129 %paars

        fssensor=500.0072560883655*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-18.2226   -9.9374   69.5051];
        scaleFactorAcc = [0.0048    0.0048    0.0047];
        offSetGyro = [4.0287   16.4950    7.2045];

         offSetMag = [20.5000   -9.0000   -6.5000];
         scaleFactorMag = [0.006644518272425   0.006535947712418   0.006968641114983];
         
         % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
        data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
        data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
        data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end

        [ data] = sfcorrection( data, fssensor, fs);
        
    case 130 %rood geijkt op 31-08-2018
        fssensor=500.0090237080756*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-7.159275383707154  -9.968427768136621 -22.996383598394118];
        scaleFactorAcc = [0.004782928301813   0.004783780016004   0.004769243705128];
        offSetGyro = [22.104683195592287  20.236455463728191  -1.671258034894399];
        %         offSetMag = [10 -72.5 9];
        %         scaleFactorMag = [0.983333333333333   0.980066445182724   1.038732394366197];
        offSetMag = [18 -63.5 9];
        scaleFactorMag = [0.007042253521127   0.007220216606498   0.007299270072993];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 131 
        fssensor=500.0096471370507*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-18.293431631620138 -16.751355268875955 -13.491535157847466];
        scaleFactorAcc = [0.004764442111567   0.004807807618632   0.004755462309756];
        offSetGyro = [ 14.128451031676837   0.650004843553231  12.288482030417514];
        %         offSetMag = [10 -72.5 9];
        %         scaleFactorMag = [0.983333333333333   0.980066445182724   1.038732394366197];
        offSetMag = [32.5 47.5 23];
        scaleFactorMag = [0.006920415224913   0.006688963210702   0.007194244604317];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 132 %bruin
        
        fssensor=500.0056238772711*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-17.1237   -9.1469  100.9175];
        scaleFactorAcc = [0.0048    0.0048    0.0048];
        offSetGyro = [-23.1191  -38.4158  -13.2619];
        offSetMag = [1.0000 -165.0000   47.5000];
        scaleFactorMag = [0.006802721088435   0.006578947368421   0.007117437722420];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 134 %blauw
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0053255794493*factor;
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-10.264244672219320  -9.556730307496309 -13.305529222825044];
        scaleFactorAcc = [0.004794227434523   0.004751605333635   0.004806114195076];
        offSetGyro = [-14.784707158351409   4.900216919739696  -2.855748373101952];
        offSetMag = [93.0000 -193.0000   69.5000];
        scaleFactorMag = [0.006896551724138   0.006896551724138   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 135 %groen
        fssensor=500.0081835*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-0.4258037458536  -5.7557199211044   234.6338450091886];
        scaleFactorAcc = [0.004797386632918   0.004755927697644   0.004767344935480];
        offSetGyro = [-41.210330578  22.058264462   1.0780991735];
        %         offSetMag = [30.5 -48 -41];
        %         scaleFactorMag = [0.987138263665595   0.977707006369427   1.037162162162162];
        offSetMag = [35 -39.5 -42];
        scaleFactorMag = [0.006896551724138   0.006968641114983   0.007518796992481];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        fssensor=500.0094780036039*factor;
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 136 %paars
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0090977834454*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-20.247204010798214  -3.146118678257608 -16.113665436408155];
        scaleFactorAcc = [0.004795643424585   0.004758100750102   0.004784899404441];
        offSetGyro = [-7.747185741088180   2.142120075046904  -4.123358348968105];
        offSetMag = [-100.5000 -168.0000  133.5000];
        scaleFactorMag = [0.006968641114983   0.006802721088435   0.007272727272727];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 137 %wit
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0091610215018*factor;
        
% Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-12.140389213761864 -13.990081450240496   7.877651500301681];
        scaleFactorAcc = [0.004786447014272   0.004775163011536   0.004754973644341];
        offSetGyro = [-30.636297903109185   1.387924801156905   7.551699204627621];
        offSetMag = [247.500   38.000  107.500];
        scaleFactorMag = [0.006872852233677   0.006849315068493   0.007272727272727];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 138 %zwart
        %     fssensor=500.0081835*factor;
        fssensor=500.0074018020477*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-20.3405   -7.0587   41.2612];
        scaleFactorAcc = [0.0048    0.0048    0.0047];
        offSetGyro = [7.9428    7.9946   11.2541];
        offSetMag = [18.0000  -46.5000  -11.0000];
        scaleFactorMag = [ 0.006849315068493   0.006734006734007   0.007142857142857];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 139%lila
        %fssensor=500.0090*factor;
        %     fssensor=500.0081835*factor;
        fssensor=500.0115911681607*factor;
        calibratedforAccelerationandGyros=0;
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 140 %paars geijkt op 31-08-2018
        fssensor= 500.0089867210488*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration Factors
        offSetAcc = [-18.519112011435027  -2.209502973919825  63.807164735776269];
        scaleFactorAcc = [0.004744685995240   0.004807074670161   0.004786313602276];
        offSetGyro = [38.072302558398221  15.535409714497590  19.609936967000372];
        %         offSetMag = [106.5000  196.5000 -162.5000];
        %         scaleFactorMag = [0.978563772775991   0.984897518878101   1.038680318543800];
        offSetMag = [106.5000  188.0000 -159.5000];
        scaleFactorMag = [0.007017543859649   0.006944444444444   0.007220216606498];
        
        D = [0.011539562885030  -0.001042564683561   0.001217778799347;...
            0.002718191121500   0.011426064427896   0.001190762866173;...
            -0.003554015123864  -0.003062254770886   0.012474078331570];
        o_0 = 1.0e+02 * [1.149465723296800 1.994641938900366 -1.640419292302745]';
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
            
            %         data(:,7) = xMag;
            %         data(:,8) = yMag;
            %         data(:,9) = zMag;
            %         for i = 1:size(data,1)
            %             data(i,7:9) = (D*(data(i,7:9)'-o_0))';
            %         end
        end
        [ data] = sfcorrection( data, fssensor, fs);
    case 141 %geel
        %fssensor=500.0090*factor;
        fssensor=500.0069707259026*factor;
        %fssensor= 500;
         % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-0.622712930926355 -11.990606608528424 -30.591119826040995];
        scaleFactorAcc = [0.004805513980565   0.004800111510216   0.004774762371755];
        offSetGyro = [-41.167556742323100   7.862483311081442  -3.034045393858478];
        offSetMag = [88.5000   17.5000   46.5000];
        scaleFactorMag = [0.006872852233677   0.006825938566553   0.007168458781362];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
        
    case 142%bruin
        %fssensor=500.0090*factor;
        fssensor=500.0068426816835*factor;
        %fssensor= 500;
        
        calibratedforAccelerationandGyros=1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [-21.8196   -6.0562  -39.4193];
        scaleFactorAcc = [0.004754991729367   0.004778046746121   0.004758837061112];
        offSetGyro = [-7.324475524475525  16.611888111888113   9.377622377622378];
        
        offSetMag = [85.5000    5.0000   -8.5000];
        scaleFactorMag = [0.006872852233677   0.006849315068493   0.007117437722420];
        offSetMag =[81.5 3.5 -11.5];%Ookmeerhal okt2019
        scaleFactorMag = [0.00727272727272727  0.00701754385964912  0.00766283524904215];%Ookmeerhal okt2019
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 143 %oranje
        %fssensor=500.0090*factor;
        fssensor=500.0076707267017*factor;
        calibratedforAccelerationandGyros=1;
        calibratedforMagneticfield = 1;
        
        offSetAcc = [-31.935910335357221  -8.808719271461996  50.758607331534449];
        scaleFactorAcc = [0.004761964182447   0.004759954845753   0.004774498449556];
        offSetGyro = [-15.352691218130312 -13.787535410764873  40.640934844192635];
        
        offSetMag = [7.5000  -46.5000   16.0000];
        scaleFactorMag = [0.006920415224913   0.006734006734007   0.007246376811594];
        offSetMag =[9  -47  17];%Ookmeerhal okt 2019
        scaleFactorMag =[0.00694444444444444   0.00704225352112676  0.00746268656716418];%Ookmeerhal okt 2019
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 144 %blauw
        %fssensor=500.0090*factor;
        fssensor=500.0097707290988*factor;
        % fssensor= 500;
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [ -29.351650666547357  -0.941966316158300  11.701747739181315];
        scaleFactorAcc = [0.004747833203735   0.004847548572721   0.004771598765636];
        offSetGyro = [-12.853010164190774  14.955238467552775   5.055121188428460];
        offSetMag = [54     4    22];
        scaleFactorMag = [0.006711409395973   0.006622516556291   0.007142857142857];
        offSetMag =[58  1.5   19];%Ookmeerhal okt 2019
        scaleFactorMag =[0.00699300699300699   0.00701754385964912  0.00729927007299270];%Ookmeerhal okt 2019
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 145 %groen
        fssensor=500.0088987724710*factor;
        
        % Denote if sensor is calibrated
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibration factors
        offSetAcc = [-28.334086811906104  -7.551935793748385  -9.182151201963279];
        scaleFactorAcc = [0.004795560231443   0.004798141980063   0.004764167474799];
        offSetGyro = [3.908893709327549  -7.015907447577730   9.374186550976139];
        offSetMag = [51     9   117];
        scaleFactorMag = [0.007042253521127   0.006993006993007   0.007142857142857];
        
        offSetMag = [47 12 113.5];%Ookmeerhal okt 2019
        scaleFactorMag =  [0.00729927007299270  0.00714285714285714  0.00760456273764259];%Ookmeerhal okt 2019
        
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        [ data] = sfcorrection( data, fssensor, fs);
    case 147 %wit
        %fssensor=500.0090*factor;
        fssensor=500.0089493299612*factor;%nov 2019
        %fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [ -12.774519697581241 -14.909277225086498 -41.350607296662588];
        scaleFactorAcc = [0.004781554765565   0.004751261831088   0.004773410316398];
        offSetGyro = [23.007649696649960   2.599050382484832   3.260353468741757];
        offSetMag = [-19.0000   16.5000   92.5000];
        scaleFactorMag = [0.006993006993007   0.006825938566553   0.007220216606498];
        offSetMag = [-25  14.5  95.5];%Ookmeerhal okt 2019
        scaleFactorMag =[0.00719424460431655   0.00716845878136201  0.00766283524904215];%Ookmeerhal okt 2019
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs);
        
        
    case 170 %rood
        fssensor= 500.0101545964781*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-5.468298152391071 -20.155233139410370 -63.331547528268629];
        scaleFactorAcc = [0.004767550403933   0.004783761473892   0.004757964050935];
        offSetGyro = [-19.687861271676301  11.137076796036334 -13.343517753922379];
        offSetMag = [101.0000   19.5000   82.5000];
        scaleFactorMag = [0.006896551724138   0.006920415224913   0.007380073800738];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
                
        [ data] = sfcorrection( data, fssensor, fs);  
       
    case 171 %geel
        fssensor= 500.0140902125862*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-12.816384023289061 -18.515049951253218  18.926696080129091];
        scaleFactorAcc = [0.004797305631826   0.004749986207646   0.004778003938556];
        offSetGyro = [4.547963206307490 -10.988611476127902  24.641699518177838];
        offSetMag = [62.5000  -30.0000   45.0000];
        scaleFactorMag = [0.006825938566553   0.007042253521127   0.007352941176471];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 172 %bruin

        fssensor= 500.0097801150700*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-3.402465144154917 -17.416842879934279 -40.195328417772203];
        scaleFactorAcc = [0.004792606480589   0.004797584262252   0.004762831998848];
        offSetGyro = [-5.277450455275844   4.407070166041779   1.336368505623996];
        offSetMag = [63.5000  -23.5000  171.5000];
        scaleFactorMag = [0.006920415224913   0.006968641114983   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 173 %oranje

        fssensor= 500.0109862621018*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-1.495471730685722 -23.753588467003169  49.053120310349755];
        scaleFactorAcc = [0.004809911406180   0.004774996947684   0.004801046830019];
        offSetGyro = [-30.906661502711078   0.702943454686290  -1.665375677769171];
        offSetMag = [-87.0000  -17.5000   94.5000];
        scaleFactorMag = [0.006896551724138   0.006779661016949   0.007434944237918];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 174 %blauw

        fssensor= 500.0108161701744*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-11.026261841822929 -22.812958876031757 -20.592223043063427];
        scaleFactorAcc = [0.004770872793298   0.004762221335579   0.004784898132647];
        offSetGyro = [-1.761841227484990   4.364242828552368   5.250166777851901];
        offSetMag = [9.5000  -28.0000  135.5000];
        scaleFactorMag = [0.006389776357827   0.006250000000000   0.006734006734007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 175 %groen
        fssensor= 500.0092442077927*factor;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-3.973094183802232 -23.294136049219674 -86.979758226894432];
        scaleFactorAcc = [0.004763468982809   0.004803357947183   0.004767334549406];
        offSetGyro = [10.944773175542407  18.145956607495069  -9.732412886259040];
        offSetMag = [22.0000   44.5000  -51.0000];
        scaleFactorMag = [0.006993006993007   0.006920415224913   0.007299270072993];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 176 %paars

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-7.943143143560405 -26.478963071707085 -60.459842779658175];
        scaleFactorAcc = [0.004786243541001   0.004773918108692   0.004753565657868];
        offSetGyro = [-6.106926698049764  -7.513786146603900  -3.749495628782784];
        offSetMag = [-19.5000   -2.0000  -45.0000];
        scaleFactorMag = [0.007067137809187   0.007042253521127   0.007352941176471];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 177 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-0.960727063570403 -17.964611981115127 -16.184438115928515];
        scaleFactorAcc = [0.004754688281408   0.004779266784401   0.004803949581342];
        offSetGyro = [-3.052201257861635 -13.785534591194969  20.476729559748428];
        offSetMag = [-84.5000   33.5000   65.0000];
        scaleFactorMag = [0.006825938566553   0.006644518272425   0.007246376811594];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 178 %zwart

        fssensor= 500.0104909594157;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-6.914013174590877 -17.398244922106187  67.748873321339602];
        scaleFactorAcc = [0.004774746025321   0.004800775319292   0.004782438307569];
        offSetGyro = [-29.653598971722364  15.074550128534705  15.327763496143959];
        offSetMag = [96.0000  -77.5000   59.5000];
        scaleFactorMag = [0.007407407407407   0.006920415224913   0.007380073800738];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 180 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        % CALIBRATED: 17-10-2019     
        offSetAcc = [-11.5601     -29.4682     -68.7124];
        scaleFactorAcc = [0.0047778   0.0047882    0.004793];
        offSetGyro = [-6.11639      15.8526     -7.39256];
        offSetMag = [153    -3    86];
        scaleFactorMag = [0.007092198581560   0.007142857142857   0.007299270072993];
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 181 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % CALIBRATED: 17-10-2019
        % calibration factors
        offSetAcc = [-9.477567188173794 -22.021977223244335 -66.488226567926063];
        scaleFactorAcc = [0.004790886165392   0.004803887211526   0.004799808708117];
        offSetGyro = [-8.684766214177978   3.007088989441931  -4.086274509803921];
        offSetMag = [18   -50   129];
        scaleFactorMag = [0.0069    0.0069    0.0074];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 182 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %CALIBRATED: 17-10-2019
        % calibration factors
        offSetAcc = [-1.523682743502150 -24.830795422801543 -73.447368023271679];
        scaleFactorAcc = [0.004764129797335   0.004768832503901   0.004787821398709];
        offSetGyro = [-16.014179894179893  10.965079365079365  -1.556402116402116];
        offSetMag = [-4.0000  -55.5000  128.0000];
        scaleFactorMag = [0.0068    0.0068    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 183 %wit

        fssensor= 500.0067703890265;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %CALIBRATED: 17-10-2019        
        % calibration factors
        offSetAcc = [8.658312639210294 -21.457613488816150  43.075903507274575];
        scaleFactorAcc = [0.004807090931980   0.004807225210270   0.004777975085733];
        offSetGyro = [-3.649589089001574   1.913271550970449   2.308620388179752];
        offSetMag = [9.0000  -35.5000  183.5000];
        scaleFactorMag = [0.0068    0.0066    0.0070];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 184 %wit

        fssensor= 500.0101555835398;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %CALIBRATED: 17-10-2019
        % calibration factors
        offSetAcc = [-0.326808432501821 -23.680727334959101 -32.467730820954216];
        scaleFactorAcc = [0.004772164744082   0.004796109070311   0.004760737600650];
        offSetGyro = [31.332064993829700 -16.546277252159605  15.042060880296175];
        offSetMag = [10.0000 -111.5000  158.5000];
        scaleFactorMag = [0.0068    0.0068    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 185 %wit

        fssensor= 500.0090271853688;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-5.079964776223164 -32.428242187907358  66.230957997893597];
        scaleFactorAcc = [0.004779286241313   0.004771116314568   0.004789269358591];
        offSetGyro = [7.514356435643564  -1.041419141914191  22.390924092409239];       
        offSetMag = [90   -38   174];
        scaleFactorMag = [0.0067    0.0066    0.0069];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 186 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated 17-10-2019
        % calibration factors
        offSetAcc = [-7.8501  -28.7632 -108.1231];
        scaleFactorAcc = [0.004755137910780   0.004776623891574   0.004817893846156];
        offSetGyro = [-24.265597713922844  -3.896015240514367  -2.063343387839339];
        offSetMag = [85.5000  -59.5000   36.5000];
        scaleFactorMag = [0.0066    0.0067    0.0070];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 187 %wit

        fssensor= 500.0104909594157;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 17-10-2019
        % calibration factors
        offSetAcc = [ -0.815197636218386 -24.295300804431577 -36.167965767092255];
        scaleFactorAcc = [0.004813795119538   0.004784931647019   0.004792560014691];
        offSetGyro = [-31.288236166740841   3.280967215546655   4.396825396825397];
        offSetMag = [107    -6   139];
        scaleFactorMag = [0.0070    0.0068    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 188 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 17-10-2019
        % calibration factors
        offSetAcc = [ -11.966186666258295 -23.376224831426157 -30.642930847285129];
        scaleFactorAcc = [0.004798058561434   0.004789129473091   0.0048015183390768];
        offSetGyro = [-10.044010195412065   1.459133389974511  12.283092608326253];
        offSetMag = [111.5000   17.5000  197.5000];
        scaleFactorMag = [0.0068    0.0068    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 190 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [ -12.774519697581241 -14.909277225086498 -41.350607296662588];
        scaleFactorAcc = [0.004781554765565   0.004751261831088   0.004773410316398];
        offSetGyro = [23.007649696649960   2.599050382484832   3.260353468741757];
        offSetMag = [-19.0000   16.5000   92.5000];
        scaleFactorMag = [0.006993006993007   0.006825938566553   0.007220216606498];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 191 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % CALIBRATED: 18-10-2019
        % calibration factors
        offSetAcc = [5.141960341675485 -16.061892882490611  14.954641808668157];
        scaleFactorAcc = [0.004794439240437   0.004822713934608   0.004801161725304];
        offSetGyro = [-12.002622377622378   1.144580419580420   7.656993006993007];
        offSetMag = [53   -26   159];
        scaleFactorMag = [0.0068    0.0067    0.0070];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 192 %wit

        fssensor= 500.0096167127978;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [-1.266908646017328 -29.299372539684441 -37.025759470489561];
        scaleFactorAcc = [0.004785953302859   0.004798810135809   0.004772729700340];
        offSetGyro = [-3.889603860848582   6.004624974864267   1.729539513372210];
        offSetMag = [153    26    97];
        scaleFactorMag = [0.0068    0.0068    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 193 %wit

        fssensor= 500.0096167127978;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [  -9.540400189015827 -21.205795852465030 -12.111736834379599];
        scaleFactorAcc = [0.004782959234797   0.004751990274206   0.004781804325642];
        offSetGyro = [-32.351431759018226  -6.103632081318954  -5.104003966778232];
        offSetMag = [128.0000    3.0000  132.5000];
        scaleFactorMag = [0.0068    0.0068    0.0071];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 194 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-16.495249850807113 -26.097478361903541 -98.251251758269177 ];
        scaleFactorAcc = [0.004760822084088   0.004790751167315   0.004762086567927];
        offSetGyro = [1.471690796277146 -15.116339193381593  -4.857161323681489];
        offSetMag = [16.0000   72.5000  113.0000];
        scaleFactorMag = [0.0068    0.0067    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 195 %wit

        fssensor= 500.0104909594157;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [-6.582129473697591 -23.696193705011638 -41.174792418370430];
        scaleFactorAcc = [0.004776028628874   0.004744441991746   0.004809253711339];
        offSetGyro = [-3.228364593616321  -7.071076011846002  18.027147087857848];
        offSetMag = [67.5000   34.5000  100.0000];
        scaleFactorMag = [0.0070    0.0070    0.0073];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 196 %wit

        fssensor= 500.0078987871976;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [-18.079063409608352 -18.465360958578231 -52.643515596640555];
        scaleFactorAcc = [0.004795803054963   0.004771890584778   0.004799590709759];
        offSetGyro = [-2.966180135279459   1.604485582057672 -10.303132787468851];
        offSetMag = [48.5000   97.0000   77.5000];
        scaleFactorMag = [0.0071    0.0071    0.0073];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 197 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [ 2.642983003682616 -26.392727821558424  26.085184912662498];
        scaleFactorAcc = [0.004787505542892   0.004770799805059   0.004768317769255];
        offSetGyro = [-4.225546975546975  -2.730694980694981   0.187419562419562];
        offSetMag = [86.0000  -20.5000  179.0000];
        scaleFactorMag = [0.0068    0.0067    0.0071];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 198 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-29.711134931291781 -24.089117517344448 -65.464329577971284];
        scaleFactorAcc = [0.004784899606774   0.004800856303356   0.004786633513124];
        offSetGyro = [-11.644754218635363  -1.396038151137197   7.306089508437271];
        offSetMag = [89.5000  -13.5000  136.5000];
        scaleFactorMag = [0.0068    0.0067    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 200 %wit

        fssensor= 500.0087424661797;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        %Calibrated: 18-10-2019
        % calibration factors
        offSetAcc = [-8.418995839732816 -17.570968631689993 -35.934376627724532];
        scaleFactorAcc = [0.004780675219660   0.004805879613831   0.004761653276420];
        offSetGyro = [7.523788674839463   2.518242848803269   3.200963222416813];
        offSetMag = [27.5000   -8.0000  101.0000];
        scaleFactorMag = [0.0069    0.0070    0.0072];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 201 %geel

        fssensor= 500.0104909594157;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-15.170029201038801 -16.239913994822359 -55.066990727136158];
        scaleFactorAcc = [0.004787421534259   0.004776255098312   0.004748042577015];
        offSetGyro = [-4.036115569823435   1.687800963081862  17.339486356340288];
        offSetMag = [49.5000  -95.5000   44.5000];
        scaleFactorMag = [0.007017543859649   0.006968641114983   0.007490636704120];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 202 %bruin

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-9.07683     -30.2608     -2.40714];
        scaleFactorAcc = [0.0047619   0.0047643   0.0047732];
        offSetGyro = [-20.2649      3.25083      4.44628];
        offSetMag = [5.5000   22.0000   93.5000];
        scaleFactorMag = [0.006968641114983   0.006944444444444   0.007168458781362];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 203 %oranje

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-12.1926     -21.2954     -48.3616];
        scaleFactorAcc = [0.0048085   0.0047672   0.0048153];
        offSetGyro = [-3.1145      -1.855      7.2665];
        offSetMag = [75.0000  -29.5000    2.5000];
        scaleFactorMag = [0.006756756756757   0.006968641114983   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 204 %blauw

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-2.68002     -22.5668     -18.2541];
        scaleFactorAcc = [0.0047665   0.0047832   0.0047771];
        offSetGyro = [-23.869      17.4016      9.61448];
        offSetMag = [161.5000    4.5000   70.0000];
        scaleFactorMag = [0.007067137809187   0.007272727272727   0.007692307692308];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 205 %groen

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [1.66988     -25.0214     -87.2238];
        scaleFactorAcc = [0.0047718   0.0047799   0.0047547];
        offSetGyro = [-2.33786     -17.9124       19.351];
        offSetMag = [139.5000  -16.5000   23.0000];
        scaleFactorMag = [0.006825938566553   0.006872852233677   0.007246376811594];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        
    case 206 %paars

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-9.16562     -22.2347     -55.2153];
        scaleFactorAcc = [0.0047557   0.0048111   0.0047588];
        offSetGyro = [-29.852      9.79927      -11.052];
        offSetMag = [-39.0000   76.5000   94.0000];
        scaleFactorMag = [0.007092198581560   0.006968641114983   0.007299270072993];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
       case 208 %zwart

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-20.1855       -21.28      36.9001];
        scaleFactorAcc = [0.004791   0.0047878   0.0047565];
        offSetGyro = [-1.24248      12.1425     0.297345];
        offSetMag = [7.5000   12.0000   91.5000];
        scaleFactorMag = [0.007017543859649   0.006896551724138   0.007380073800738];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 210 %rood

        fssensor= 500.0096167127978;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [20.9961     -23.7138      -78.141];
        scaleFactorAcc = [0.0047839   0.0047719   0.0047356];
        offSetGyro = [9.71723      15.9133      10.7172];
        offSetMag = [-0.5000   26.5000   85.5000];
        scaleFactorMag = [0.007117437722420   0.006968641114983   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 211 %geel

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-18.876     -21.7701        6.624];
        scaleFactorAcc = [0.0047586   0.0047851   0.0047475];
        offSetGyro = [-11.4417     -10.5537      5.98916];
        offSetMag = [-19.5000   12.0000  -22.0000];
        scaleFactorMag = [0.006872852233677   0.006944444444444   0.007194244604317];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 212 %bruin

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-13.8973     -24.4587     -65.1268];
        scaleFactorAcc = [0.004773   0.0047617   0.0048083];
        offSetGyro = [-23.5944      4.70649      6.64012];
        offSetMag = [-0.5000   -7.0000  124.5000];
        scaleFactorMag = [0.006872852233677   0.006993006993007   0.007272727272727];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 213 %oranje

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-12.5526     -24.5543     -54.3827];
        scaleFactorAcc = [0.00478   0.0047841   0.0047486];
        offSetGyro = [-1.4226      1.1839     -5.1093];
        offSetMag = [22.5000   -2.0000  104.0000];
        scaleFactorMag = [0.006872852233677   0.006849315068493   0.007299270072993];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 214 % groen

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-20.296     -21.4327     -49.8359];
        scaleFactorAcc = [0.0047859   0.0047846   0.0047849];
        offSetGyro = [-13.7126       4.2999      13.2257];
        offSetMag = [-29.5000   -6.5000  158.0000];
        scaleFactorMag = [0.007067137809187   0.007017543859649   0.007352941176471];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 215 %blauw

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-16.9638     -13.6543     -6.12133];
        scaleFactorAcc = [0.0047534   0.0047714   0.0047422];
        offSetGyro = [-23.6214      14.2561     -6.95714];
        offSetMag = [46.0000  -18.0000   50.5000];
        scaleFactorMag = [0.006711409395973   0.006666666666667   0.007272727272727];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 216 %paars

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-17.7488     -14.2532      5.58994];
        scaleFactorAcc = [0.0047736   0.0047637   0.0047867];
        offSetGyro = [-14.2155      -10.403      9.29151];
        offSetMag = [23.0000   -4.5000  191.5000];
        scaleFactorMag = [0.006944444444444   0.006920415224913   0.007380073800738];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 217 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-15.3718     -23.6356     -56.0229];
        scaleFactorAcc = [0.0047545   0.0047452   0.0048043];
        offSetGyro = [-0.393258     -19.2616     -3.84109];
        offSetMag = [101.0000  -25.5000  111.0000];
        scaleFactorMag = [0.006849315068493   0.006825938566553   0.007246376811594];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 218 %zwart

        fssensor= 500.0085005280953;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-21.5883     -19.3455     -80.8439];
        scaleFactorAcc = [0.0047468   0.0047596   0.0047601];
        offSetGyro = [-5.85333     -21.1187     -7.18133];
        offSetMag = [27.0000   42.5000  149.5000];
        scaleFactorMag = [0.006711409395973   0.006920415224913   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 220 %utrecht

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-22.3608     -24.5364      14.6022];
        scaleFactorAcc = [0.0047616   0.0047915    0.004763];
        offSetGyro = [-8.72611     -6.11624     -15.4634];
        offSetMag = [44.0000    5.5000  188.0000];
        scaleFactorMag = [0.006944444444444   0.006920415224913   0.007299270072993];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 221 %ijsselstein

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-11.9648     -18.7072      2.36391];
        scaleFactorAcc = [0.0048127   0.0047723   0.0047827];
        offSetGyro = [-15.8988      6.48587      22.5871];
        offSetMag = [166.0000   46.5000  131.0000];
        scaleFactorMag = [0.006756756756757   0.006779661016949   0.007092198581560];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 222 %paarsbruin

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-21.253     -18.1583      76.2366];
        scaleFactorAcc = [0.0047805   0.0047973   0.0047633];
        offSetGyro = [8.60438      19.4358     0.713139];
        offSetMag = [-80.5000    9.0000  -22.0000];
        scaleFactorMag = [0.007067137809187   0.007042253521127   0.007352941176471];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 223 %oranjezwart

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-6.96752     -26.8201      -2.1428];
        scaleFactorAcc = [0.0048061   0.0047906   0.0047981];
        offSetGyro = [-10.2817     -5.40597     -3.31992];
        offSetMag = [101.5000  -23.0000   43.5000];
        scaleFactorMag = [0.006968641114983   0.006993006993007   0.007272727272727];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 224 %groenwit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-19.4487     -19.5734     -38.2922];
        scaleFactorAcc = [0.004784   0.0047535   0.0047676];
        offSetGyro = [-24.8511      7.51694     -2.93144];
        offSetMag = [136.0000   -7.0000  136.5000];
        scaleFactorMag = [0.006849315068493   0.006802721088435   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 225 %blauw

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-17.7376     -20.7142     -88.6971];
        scaleFactorAcc = [0.0047887   0.0047575   0.0048036];
        offSetGyro = [-7.95472     -12.7939      3.91663];
        offSetMag = [17.5000    2.0000   77.5000];
        scaleFactorMag = [0.007168458781362   0.007142857142857   0.007220216606498];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 226 % paars

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-9.5878     -21.8445      8.45491];
        scaleFactorAcc = [0.0047534   0.0047753   0.0047843];
        offSetGyro = [-33.9196     -13.7468      18.7011];
        offSetMag = [142.0000  102.0000   60.5000];
        scaleFactorMag = [0.007092198581560   0.006993006993007   0.007272727272727];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 
        case 227 %wit

        fssensor= 500;
        calibratedforAccelerationandGyros = 1;
        calibratedforMagneticfield = 1;
        
        % calibration factors
        offSetAcc = [-21.017     -22.5035     -28.1224];
        scaleFactorAcc = [0.004774   0.0047492   0.0047573];
        offSetGyro = [-27.661      1.78844      8.59198];
        offSetMag = [86.5000  -94.0000   73.5000];
        scaleFactorMag = [0.006825938566553   0.006802721088435   0.007326007326007];
        
        
        % Apply calibration
        data(:,1)=(xAcc-offSetAcc(1)).*scaleFactorAcc(1);
        data(:,2)=(yAcc-offSetAcc(2)).*scaleFactorAcc(2);
        data(:,3)=(zAcc-offSetAcc(3)).*scaleFactorAcc(3);
        data(:,4)=(xGyro-offSetGyro(1)).*0.06104*2*pi/360;%rad/s
        data(:,5)=(yGyro-offSetGyro(2)).*0.06104*2*pi/360;
        data(:,6)=(zGyro-offSetGyro(3)).*0.06104*2*pi/360;
        
        if size(data,2)==9
            data(:,7) = (xMag-offSetMag(1))*scaleFactorMag(1);
            data(:,8) = (yMag-offSetMag(2))*scaleFactorMag(2);
            data(:,9) = (zMag-offSetMag(3))*scaleFactorMag(3);
        end
        
        
        [ data] = sfcorrection( data, fssensor, fs); 

end



%% kallibratie
f=[num2str(sensnum) f(end-11:end-4)];


calibrationfactorsIndex=strfind(str, 'Scale');
for i=1: length(calibrationfactorsIndex)
    Calibrationfactor(i)=str2double(str(calibrationfactorsIndex(i)+6:calibrationfactorsIndex(i)+13));
    
end

Calibrationfactor=[Calibrationfactor(1:3) Calibrationfactor(5:7)];%temperatuur eruit

%gyro ijking is standaard in deg/s omzetten in rad/sec

Calibrationfactor(4)=Calibrationfactor(4)*2*pi/360;
Calibrationfactor(5)=Calibrationfactor(5)*2*pi/360;
Calibrationfactor(6)= Calibrationfactor(6)*2*pi/360;

if calibratedforAccelerationandGyros==0%er heeft geen ijking met zwaartekrachtsversnelling plaatsgevonden
    %dan worden de fabrieksfactoren gebruikt
    data(:,1)=data(:,1).*Calibrationfactor(1);
    data(:,2)=data(:,2).*Calibrationfactor(2);
    data(:,3)=data(:,3).*Calibrationfactor(3);
    data(:,4)=data(:,4).*Calibrationfactor(4);
    data(:,5)=data(:,5).*Calibrationfactor(5);
    data(:,6)=data(:,6).*Calibrationfactor(6);
end

if calibratedforMagneticfield==0&& size(data,2)==9
    
    data(:,7) = xMag;
    data(:,8) = yMag;
    data(:,9) = zMag;
end

%% checken of er een mechanische syncpiek gevonden kan worden binnen de opgegeven syncperiod
%data=data(50000:end,:);
syncperiod=syncperiod*fs;% syncperiod on seconden omzeten in aantal samples

%wordt gezocht
if length(data)<syncperiod
    syncperiod=length(data)-1;
end


tot=abs(diff(data(1:syncperiod,1)))+abs(diff(data(1:syncperiod,2)))+abs(diff(data(1:syncperiod,3)));
[totmax, istart]=max(tot);


mechanicalsync='no';
if totmax>30 %als er een mechanische syncpiek wordt signaal voor sync verwijderd
    %start=find(diff(tot(istart-200*fs/1000:istart))>10);
%     start=find(abs(diff(tot(istart-200*fs/1000:istart)))>40);%door 60 te nemen ipv 20 worden voorhobbels eruit gehaald als sensors war voorschudden voor de sync in houten doosje
    start = istart;
    if isempty(start)==0
%         start=start(1)+istart-200*fs/1000;
        
        data=data(start+1000*fs/1000:end,:);%1 sec voorbij syncpiek zodat signaal niet begint met restand syncpiek
        mechanicalsync='yes';
    else
        war=warndlg('no synpeak detected!! wait 2 secs','warning');
        %er=errordlg('no synpeak detected!!','warning')
        pause(2)
        close(war)
        [data,mechanicalsync]=DetectEndSyncpeak(data,syncperiod,fs);%er wordt nog gekeken of er aan het einde van de file een syncpiek zit
    end
else
    war=warndlg('no synpeak detected!! wait 2 secs','warning');
    %er=errordlg('no synpeak detected!!','warning')
    pause(2)
    close(war)
    [data]=DetectEndSyncpeak(data,syncperiod,fs);%er wordt nog gekeken of er aan het einde van de file een syncpiek zit
end

dat=struct('filename',f,'data',data,'samplerate', fs,'mechanicalsync', mechanicalsync);

%%%%%% save metadata   %%%%%%%
info.sensorNumber = sensnum2;   %sensor number

% index of time synchronization
if exist('start') == 0
info.synchronizationIndexNumber = 1;
else
    info.synchronizationIndexNumber = start+fs;
end
info.exactSampleFrequencySensor = fssensor;

% calibration factors
info.calibrationFactors.offSetAcc = offSetAcc;
info.calibrationFactors.scaleFactorAcc = scaleFactorAcc;
info.calibrationFactors.offSetGyro = offSetGyro;
info.calibrationFactors.scaleFactorMag = scaleFactorMag;
info.calibrationFactors.offSetMag = offSetMag; 

save(name,'dat')


end

%if a syncpeak at the beginning of the measurement wasn't found, there is an addiiotnal check for
%a syncpeak at the end of teh measurement, just before the sensors were switched of
%in case an endsyncpeak is found this is followed by an conservative
%estimation of the signal length

function [data,mechanicalsync]=DetectEndSyncpeak(data,syncperiod,fs)
referencelist=(1:5:1000)';
toteind=abs(diff(data(end-syncperiod:end,1)))+abs(diff(data(end-syncperiod:end,2)))+abs(diff(data(end-syncperiod:end,3)));
[totmaxeind, iendofstart]=max(toteind);
if totmaxeind>30
    endofstart = iendofstart+length(data)-syncperiod;
    if isempty(endofstart)==0
        
        number=floor(endofstart/syncperiod-0.5);
        indexref=find(referencelist>number);
        number=referencelist(indexref(1)-1);%
        % often there are signals of more sensors in the same struct and these all have to get the same length
        % even though the sensors are not switched on and off at exactly the same time
        % this causes 'number' to differ potentially by one syncperiod 
        % to prevent this from happening, there is a second step to make the estimation of number more conservative
        %The disadvantage is that you loose additional signal length (number times the syncperiod) at the beginning of your
        %signals, but this  rarely is a problem
        
        predictedsignallength=number*syncperiod;
        begin=endofstart-predictedsignallength;
        data=data(begin:endofstart+1000*fs/1000,:);
        mechanicalsync='yes';
        war=warndlg('END-synpeak detected  wait 2 secs','warning');
        
        pause(2)
        close(war)
    else
        war=warndlg('no END-synpeak detected either!! wait 2 secs','warning');
        
        pause(2)
        close(war)
    end
else
    
    war=warndlg('no END-synpeak detected either!! wait 2 secs','warning');
    pause(2)
    close(war)
end

end