function [qRotate, startMovement, endMovement] = getRotationPelvis(gyro,fs,iViewStart,iViewEnd,iStart,iEnd)
%% qRotate -- calculates quaternion necessary to rotate data to align with
%             body segment
%   Date Created:           Last modified:              Author:
%    09-01-2018               14-05-2019              Erik Wilmes
%
%% get calibration movement period

time = [0:size(gyro,1)-1]./fs;

if nargin ==2 || nargin ==4
    
    checkCalib = 0;
    
    while checkCalib == 0
    figure;
    % set figure to screensize, comment to undo
    set(gcf, 'Position', get(0, 'Screensize'));
    
    hold on;
    title('Zoom to bow movement. Press Enter. // Click start bow movement, then click end bow movement')
    xlabel('Time (s)')
    
    plot(time,gyro)
    
    if nargin ==4
        xlim([time(iViewStart) time(iViewEnd)])
    end
    set(gca,'FontSize',17)
    hold off;
    zoom on;
    pause();
    zoom off;
    % select calibration period from figure
    [calib,~] = ginput(2);
    
    % close figure
    close
    
    % Calibrate position IMUs on body
    iStart = round(calib(1)*fs);        % start time calibration period
    iEnd = round(calib(2)*fs);          % end time calibration period
    
    checkCalib = checkPlot(time,gyro,calib(1),calib(2));
    
    end
end
% integrate over bow
calAngles = cumsum(gyro(iStart:iEnd,:),1)./fs;

% preallocate
angleNorm = zeros(length(calAngles(:,1)),1);

% calculate absolute angle rotation
for i = 1: length(calAngles(:,1))
    angleNorm(i) = norm(calAngles(i,:));
end

% extract max angle
[~,iMaxAng] = max(abs(angleNorm));

for i = 1: length(calAngles(:,1))
    calAngles(i,:) = calAngles(i,:)./angleNorm(i);
end

theta = atan2(calAngles(iMaxAng,3),calAngles(iMaxAng,1))+pi/2;

% rotate quaternion
n1 = [0 1 0];
qRotate = quaternInv([cos(theta/2), n1*sin(theta/2)]);

startMovement = iStart/fs;
endMovement = iEnd/fs;
end
function check = checkPlot(time,gyro,calStart,calEnd)

check = [];
s.f = figure;
hold on;
title('Check if calibration was entered correctly? Answer with yes or no.')
plot(time,gyro)
xlim([calStart-10 calEnd+10])
line([calStart calStart],get(gca,'Ylim'),'Color','k','LineStyle','--','LineWidth',2)
line([calEnd calEnd],get(gca,'Ylim'),'Color','k','LineStyle','--','LineWidth',2)
ylabel('Angular velocity rad/s')

s.noButton = uicontrol('Style','PushButton',...
    'Units','Normalized',...
    'Position',[.6 .12 .3 .1],...
    'String','No',...
    'CallBack',{@answerNo});

s.yesButton = uicontrol('Style','PushButton',...
    'Units','Normalized',...
    'Position',[.2 .12 .3 .1],...
    'String','Yes',...
    'CallBack',{@answerYes});
uiwait

    function answerNo(s,event)
        check = 0;
        uiresume
    end

    function answerYes(s,event)
        check = 1;
        uiresume
    end

close(s.f)
end
